@@ -3,6 +3,7 @@ package postgres
 import (
 	"context"
 	"fmt"
+	"os"
 	"strconv"
 	"strings"
 
@@ -111,7 +112,7 @@ func runMachineConfigUpdate(ctx context.Context, app *api.AppCompact) error {
 
 		MinPostgresHaVersion         = "0.0.33"
 		MinPostgresStandaloneVersion = "0.0.7"
-		MinPostgresFlexVersion       = "0.0.3" // Not currently supported
+		MinPostgresFlexVersion       = "0.0.6"
 	)
 
 	machines, releaseLeaseFunc, err := mach.AcquireAllLeases(ctx)
@@ -120,12 +121,11 @@ func runMachineConfigUpdate(ctx context.Context, app *api.AppCompact) error {
 		return fmt.Errorf("machines could not be retrieved")
 	}
 
-	if app.ImageDetails.Repository == "flyio/postgres-flex" {
-		return fmt.Errorf("this feature is not currently supported for this image type")
-	}
-
-	if err := hasRequiredVersionOnMachines(machines, MinPostgresHaVersion, MinPostgresFlexVersion, MinPostgresStandaloneVersion); err != nil {
-		return err
+	_, dev := os.LookupEnv("FLY_DEV")
+	if !dev {
+		if err := hasRequiredVersionOnMachines(machines, MinPostgresHaVersion, MinPostgresFlexVersion, MinPostgresStandaloneVersion); err != nil {
+			return err
+		}
 	}
 
 	leader, err := pickLeader(ctx, machines)
@@ -133,9 +133,25 @@ func runMachineConfigUpdate(ctx context.Context, app *api.AppCompact) error {
 		return err
 	}
 
-	requiresRestart, err := updateStolonConfig(ctx, app, leader.PrivateIP)
-	if err != nil {
-		return err
+	manager := flypg.StolonManager
+	if leader.ImageRef.Repository == "flyio/postgres-flex" {
+		manager = flypg.ReplicationManager
+	}
+
+	requiresRestart := false
+
+	switch manager {
+	case flypg.ReplicationManager:
+		requiresRestart, err = updateFlexConfig(ctx, app, leader.PrivateIP)
+		if err != nil {
+			return err
+		}
+	default:
+		requiresRestart, err = updateStolonConfig(ctx, app, leader.PrivateIP)
+		if err != nil {
+			return err
+		}
+
 	}
 
 	if requiresRestart {
@@ -164,22 +180,195 @@ func runMachineConfigUpdate(ctx context.Context, app *api.AppCompact) error {
 	return nil
 }
 
-func runNomadConfigUpdate(ctx context.Context, app *api.AppCompact) error {
-	var (
-		io       = iostreams.FromContext(ctx)
-		colorize = io.ColorScheme()
+func updateStolonConfig(ctx context.Context, app *api.AppCompact, leaderIP string) (bool, error) {
+	io := iostreams.FromContext(ctx)
 
+	restartRequired, changes, err := resolveConfigChanges(ctx, app, flypg.StolonManager, leaderIP)
+	if err != nil {
+		return false, err
+	}
+
+	fmt.Fprintln(io.Out, "Performing update...")
+	cmd, err := flypg.NewCommand(ctx, app)
+	if err != nil {
+		return false, err
+	}
+
+	err = cmd.UpdateSettings(ctx, leaderIP, changes)
+	if err != nil {
+		return false, err
+	}
+	fmt.Fprintln(io.Out, "Update complete!")
+
+	return restartRequired, nil
+}
+
+func updateFlexConfig(ctx context.Context, app *api.AppCompact, leaderIP string) (bool, error) {
+	var (
+		io     = iostreams.FromContext(ctx)
+		dialer = agent.DialerFromContext(ctx)
+	)
+
+	restartRequired, changes, err := resolveConfigChanges(ctx, app, flypg.ReplicationManager, leaderIP)
+	if err != nil {
+		return false, err
+	}
+
+	fmt.Fprintln(io.Out, "Performing update...")
+	leaderClient := flypg.NewFromInstance(leaderIP, dialer)
+
+	// Push configuration settings to consul.
+	if err := leaderClient.UpdateSettings(ctx, changes); err != nil {
+		return false, err
+	}
+
+	machines, err := mach.ListActive(ctx)
+	if err != nil {
+		return false, err
+	}
+
+	// Sync configuration settings for each node. This should be safe to apply out-of-order.
+	for _, machine := range machines {
+		client := flypg.NewFromInstance(machine.PrivateIP, dialer)
+
+		// Pull configuration settings down from Consul for each node and reload the config.
+		err := client.SyncSettings(ctx)
+		if err != nil {
+			return false, fmt.Errorf("failed to sync configuration on %s: %s", machine.ID, err)
+		}
+	}
+	fmt.Fprintln(io.Out, "Update complete!")
+
+	return restartRequired, nil
+}
+
+func resolveConfigChanges(ctx context.Context, app *api.AppCompact, manager string, leaderIP string) (bool, map[string]string, error) {
+	var (
+		io     = iostreams.FromContext(ctx)
+		dialer = agent.DialerFromContext(ctx)
+
+		force       = flag.GetBool(ctx, "force")
 		autoConfirm = flag.GetBool(ctx, "yes")
 	)
 
-	var MinPostgresVersion = "v0.0.32"
+	// Identify requested configuration changes.
+	changes := map[string]string{}
+	keys := []string{}
+	for key := range pgSettings {
+		val := flag.GetString(ctx, key)
+		if val != "" {
+			changes[pgSettings[key]] = val
+			keys = append(keys, pgSettings[key])
+		}
+	}
+
+	restartRequired := false
+	if !force {
+		// Query PG settings
+		pgclient := flypg.NewFromInstance(leaderIP, dialer)
+
+		settings, err := pgclient.ViewSettings(ctx, keys, manager)
+		if err != nil {
+			return false, nil, err
+		}
+
+		if len(changes) == 0 {
+			return false, nil, fmt.Errorf("no changes were specified")
+		}
+
+		changelog, err := resolveChangeLog(ctx, changes, settings)
+		if err != nil {
+			return false, nil, err
+		}
+		if len(changelog) == 0 {
+			return false, nil, fmt.Errorf("no changes to apply")
+		}
+
+		rows := make([][]string, 0, len(changelog))
+		for _, change := range changelog {
+			requiresRestart := isRestartRequired(settings, change.Path[len(change.Path)-1])
+			if requiresRestart {
+				restartRequired = true
+			}
+
+			name := strings.ReplaceAll(change.Path[len(change.Path)-1], "_", "-")
+			rows = append(rows, []string{
+				name,
+				fmt.Sprint(change.From),
+				fmt.Sprint(change.To),
+				fmt.Sprint(requiresRestart),
+			})
+		}
+		render.Table(io.Out, "", rows, "Name", "Value", "Target value", "Restart Required")
+
+		if !autoConfirm {
+			const msg = "Are you sure you want to apply these changes?"
+
+			switch confirmed, err := prompt.Confirmf(ctx, msg); {
+			case err == nil:
+				if !confirmed {
+					return false, nil, nil
+				}
+			case prompt.IsNonInteractive(err):
+				return false, nil, prompt.NonInteractiveError("auto-confirm flag must be specified when not running interactively")
+			default:
+				return false, nil, err
+			}
+		}
+	}
+
+	return restartRequired, changes, nil
+}
+
+func resolveChangeLog(ctx context.Context, changes map[string]string, settings *flypg.PGSettings) (diff.Changelog, error) {
+	// Verify that input values are within acceptible ranges.
+	// Stolon does not verify this, so we need to do it here.
+	for k, v := range changes {
+		for _, setting := range settings.Settings {
+			if setting.Name == k {
+				if err := validateConfigValue(setting, k, v); err != nil {
+					return nil, err
+				}
+			}
+		}
+	}
+
+	// Construct a map of the active configuration settings so we can compare.
+	oValues := map[string]string{}
+	for _, setting := range settings.Settings {
+		oValues[setting.Name] = setting.Setting
+	}
+
+	// Calculate diff
+	return diff.Diff(oValues, changes)
+}
+
+func isRestartRequired(pgSettings *flypg.PGSettings, name string) bool {
+	for _, s := range pgSettings.Settings {
+		if s.Name == name {
+			if s.Context == "postmaster" {
+				return true
+			}
+		}
+	}
+
+	return false
+}
+
+func runNomadConfigUpdate(ctx context.Context, app *api.AppCompact) error {
+	var (
+		client      = client.FromContext(ctx).API()
+		io          = iostreams.FromContext(ctx)
+		colorize    = io.ColorScheme()
+		autoConfirm = flag.GetBool(ctx, "yes")
+
+		MinPostgresVersion = "v0.0.32"
+	)
 
 	if err := hasRequiredVersionOnNomad(app, MinPostgresVersion, MinPostgresVersion); err != nil {
 		return err
 	}
 
-	client := client.FromContext(ctx).API()
-
 	agentclient, err := agent.Establish(ctx, client)
 	if err != nil {
 		return errors.Wrap(err, "can't establish agent")
@@ -227,130 +416,6 @@ func runNomadConfigUpdate(ctx context.Context, app *api.AppCompact) error {
 	return nil
 }
 
-func updateStolonConfig(ctx context.Context, app *api.AppCompact, leaderIP string) (bool, error) {
-	var (
-		io     = iostreams.FromContext(ctx)
-		dialer = agent.DialerFromContext(ctx)
-
-		force       = flag.GetBool(ctx, "force")
-		autoConfirm = flag.GetBool(ctx, "yes")
-	)
-
-	// Identify requested configuration changes.
-	changes := map[string]string{}
-	keys := []string{}
-	for key := range pgSettings {
-		val := flag.GetString(ctx, key)
-		if val != "" {
-			changes[pgSettings[key]] = val
-			keys = append(keys, pgSettings[key])
-		}
-	}
-
-	restartRequired := false
-	if !force {
-		// Query PG settings
-		pgclient := flypg.NewFromInstance(leaderIP, dialer)
-		settings, err := pgclient.ViewSettings(ctx, keys)
-		if err != nil {
-			return false, err
-		}
-		if len(changes) == 0 {
-			return false, fmt.Errorf("no changes were specified")
-		}
-
-		changelog, err := resolveChangeLog(ctx, changes, settings)
-		if err != nil {
-			return false, err
-		}
-		if len(changelog) == 0 {
-			return false, fmt.Errorf("no changes to apply")
-		}
-
-		rows := make([][]string, 0, len(changelog))
-		for _, change := range changelog {
-			requiresRestart := isRestartRequired(settings, change.Path[len(change.Path)-1])
-			if requiresRestart {
-				restartRequired = true
-			}
-
-			name := strings.Replace(change.Path[len(change.Path)-1], "_", "-", -1)
-			rows = append(rows, []string{
-				name,
-				fmt.Sprint(change.From),
-				fmt.Sprint(change.To),
-				fmt.Sprint(requiresRestart),
-			})
-		}
-		render.Table(io.Out, "", rows, "Name", "Value", "Target value", "Restart Required")
-
-		if !autoConfirm {
-			const msg = "Are you sure you want to apply these changes?"
-
-			switch confirmed, err := prompt.Confirmf(ctx, msg); {
-			case err == nil:
-				if !confirmed {
-					return false, nil
-				}
-			case prompt.IsNonInteractive(err):
-				return false, prompt.NonInteractiveError("auto-confirm flag must be specified when not running interactively")
-			default:
-				return false, err
-			}
-		}
-	}
-
-	cmd, err := flypg.NewCommand(ctx, app)
-	if err != nil {
-		return false, err
-	}
-
-	fmt.Fprintln(io.Out, "Performing update...")
-
-	err = cmd.UpdateSettings(ctx, leaderIP, changes)
-	if err != nil {
-		return false, err
-	}
-	fmt.Fprintln(io.Out, "Update complete!")
-
-	return restartRequired, nil
-}
-
-func resolveChangeLog(ctx context.Context, changes map[string]string, settings *flypg.PGSettings) (diff.Changelog, error) {
-	// Verify that input values are within acceptible ranges.
-	// Stolon does not verify this, so we need to do it here.
-	for k, v := range changes {
-		for _, setting := range settings.Settings {
-			if setting.Name == k {
-				if err := validateConfigValue(setting, k, v); err != nil {
-					return nil, err
-				}
-			}
-		}
-	}
-
-	// Construct a map of the active configuration settings so we can compare.
-	oValues := map[string]string{}
-	for _, setting := range settings.Settings {
-		oValues[setting.Name] = setting.Setting
-	}
-
-	// Calculate diff
-	return diff.Diff(oValues, changes)
-}
-
-func isRestartRequired(pgSettings *flypg.PGSettings, name string) bool {
-	for _, s := range pgSettings.Settings {
-		if s.Name == name {
-			if s.Context == "postmaster" {
-				return true
-			}
-		}
-	}
-
-	return false
-}
-
 func validateConfigValue(setting flypg.PGSetting, key, val string) error {
 	switch setting.VarType {
 	case "enum":
