@@ -90,6 +90,10 @@ func runFailover(ctx context.Context) (err error) {
 		return err
 	}
 
+	if leader.ImageRef.Repository == "flyio/postgres-flex" {
+		return fmt.Errorf("the 'flyio/postgres-flex' image does not currently support manual failovers")
+	}
+
 	flapsClient := flaps.FromContext(ctx)
 	dialer := agent.DialerFromContext(ctx)
 
